//Evaluate VDem State Capacity Measure//


**Import VDem Data**
clear
cd "G:\My Drive\Research Paper\State Capacity"
use vdem_qgi.dta
xtset country_id year , del(1)

**Describe Variables**
des v2x_rule v2dlencmps v2svstterr v2stfisccap  v2excrptps v2stcritrecadm v2peedueq v2clrspct

**Generate Additional Variables**
tab country_n if statecap_baseline !=.
gen wgi_new = (wbgi_cce + wbgi_gee + wbgi_rle) / 3
*egen std_statehiste05 = std(statehiste05) if year == 2010
tab e_fh_cl
replace e_fh_cl = "." if country_n == "South Africa" & year == 1972
replace e_fh_pr = "." if country_n == "South Africa" & year == 1972

destring e_fh_cl , replace force
destring e_fh_pr , replace force
destring e_fh_rol , replace force

*Sum*
des statecap*
xtsum statecap*
tabstat statecap*, s(mean sd max min n)
tabstat icrg_qog wgi_new ffp_fsi  statecap* , s(mean sd max min n)

*Non Missing*
gen miss_state_base = .
replace miss_state_base = 0 if statecap_baseline != .
replace miss_state_base = 1 if statecap_baseline == .
egen missing_state_base = total(miss_state_base) , by(country_id)
tab missing_state_base
count if missing_state == 0 & year == 1789
count if statecap_basel != . & year == 1789
*keep if icrg_qog !=. & statecap_basel != .

*Standardize*
foreach var in icrg_qog wgi_new ffp_fsi e_fh_cl e_fh_pr e_fh_rol statecap_baseline statecap_base_fiscal ///
statecap_base_fiscal_edu cato_statecapacity statecap1800_baseline v2x_polyarchy e_wbgi_vae v2xel_frefair p_polity2  statehiste05 infcap_pca {
egen min_`var' = min(`var') 
egen max_`var' = max(`var')
gen norm_`var' = (`var' - min_`var')/(max_`var' - min_`var')
egen std_`var' = std(`var')
gen g_std_`var' = (std_`var' - l.std_`var' ) / std_`var'
gen d5_std_`var' = std_`var' - l5.std_`var'
gen d10_std_`var' = std_`var' - l10.std_`var'
}
tabstat norm_icrg_qog norm_wgi_new norm_ffp_fsi  norm_statecap* , s(mean sd max min n)
tabstat std_icrg_qog std_wgi_new std_ffp_fsi  std_statecap* , s(mean sd max min n)

**Correlations**
pwcorr  icrg_qog wgi_new ffp_fsi ffp_ps statecap_baseline statecap_base_fiscal statecap_base_fiscal_edu statecap1800_baseline statecapadd_baseline statehiste05 if year == 2017,  o 

pwcorr  icrg_qog wgi_new ffp_fsi statecap_baseline statecap_base_fiscal statecap_base_fiscal_edu statecap1800_baseline statecapadd_baseline infcap_pca if year == 2017,  o 

pwcorr  icrg_qog wgi_new ffp_fsi statecap_baseline statecap_base_fiscal statecap_base_fiscal_edu statecap1800_baseline statecapadd_baseline std_infcap_pca if year == 2015,  o 


*Appendix*
pwcorr  v2x_polyarchy v2jureform  p_polity e_fh_pr  icrg_qog wgi_new ffp_fsi ffp_ps statecap_base_fiscal_edu if year == 2017,  o

pwcorr  std_statehiste05 std_icrg_qog std_wgi_new std_ffp_fsi std_e_fh_rol std_statecap_baseline std_statecap_base_fiscal std_statecap_base_fiscal_edu  if year == 2017,  o 

pwcorr  icrg_qog wgi_new ffp_fsi e_fh_rol statehiste05 statecap_baseline statecap_base_fiscal statecap_base_fiscal_edu statecap1800_baseline statecapadd_baseline  if year == 2017,  o 


**Cronbach Alpha**
**Cross-section**
global c_year = 2017
*State Cap. Measure*
alpha std_statecap_basel std_icrg_qog if year == $c_year
mat a1 = r(alpha)
alpha std_statecap_basel std_wgi_new if year == $c_year
mat a2 = r(alpha)
alpha std_statecap_basel std_ffp_fsi if year == $c_year
mat a3 = r(alpha)
*alpha std_statecap_basel std_e_fh_rol if year == $c_year
*mat a4 = r(alpha)
mat A = a1 \ a2 \ a3 
mat list A

alpha std_statecap_base_fiscal std_icrg_qog if year == $c_year
mat a1 = r(alpha)
alpha std_statecap_base_fiscal std_wgi_new if year == $c_year
mat a2 = r(alpha)
alpha std_statecap_base_fiscal std_ffp_fsi if year == $c_year
mat a3 = r(alpha)
*alpha std_statecap_base_fiscal std_e_fh_rol if year == $c_year
*mat a4 = r(alpha)
mat B = a1 \ a2 \ a3 

*State Cap Comp*
alpha std_statecap_base_fiscal_edu std_icrg_qog if year == $c_year
mat a1 = r(alpha)
alpha std_statecap_base_fiscal_edu std_wgi_new if year == $c_year
mat a2 = r(alpha)
alpha std_statecap_base_fiscal_edu std_ffp_fsi if year == $c_year
mat a3 = r(alpha)
*alpha std_statecap_base_fiscal_edu std_e_fh_rol if year == $c_year
*mat a4 = r(alpha)
mat C = a1 \ a2 \ a3 

*State Cap. Measure 1800*
alpha std_statecap1800_baseline std_icrg_qog if year == $c_year
mat a1 = r(alpha)
alpha std_statecap1800_baseline std_wgi_new if year == $c_year
mat a2 = r(alpha)
alpha std_statecap1800_baseline std_ffp_fsi if year == $c_year
mat a3 = r(alpha)
*alpha std_statecap_basel std_e_fh_rol if year == $c_year
*mat a4 = r(alpha)
mat D = a1 \ a2 \ a3 
mat list D

*State Cap Addative*
alpha statecapadd_base_fiscal_edu std_icrg_qog if year == $c_year
mat a1 = r(alpha)
alpha statecapadd_base_fiscal_edu std_wgi_new if year == $c_year
mat a2 = r(alpha)
alpha statecapadd_base_fiscal_edu std_ffp_fsi if year == $c_year
mat a3 = r(alpha)
*alpha std_statecap_base_fiscal_edu std_e_fh_rol if year == $c_year
*mat a4 = r(alpha)
mat E = a1 \ a2 \ a3 

*State History*
alpha std_statehiste05 std_icrg_qog if year == $c_year
mat a1 = r(alpha)
alpha std_statehiste05 std_wgi_new if year == $c_year
mat a2 = r(alpha)
alpha std_statehiste05 std_ffp_fsi if year == $c_year
mat a3 = r(alpha)
*alpha std_statecap_basel std_e_fh_rol if year == $c_year
*mat a4 = r(alpha)
mat F = a1 \ a2 \ a3 
mat list F

mat SC = A, B, C, D, E, F
mat list SC


*Information Capacity**
alpha std_infcap_pca std_icrg_qog if year == 2015
mat a1 = r(alpha)
alpha std_infcap_pca std_wgi_new if year == 2015
mat a2 = r(alpha)
alpha std_infcap_pca std_ffp_fsi if year == 2015
mat a3 = r(alpha)
alpha std_infcap_pca std_statecap_baseline if year == 2015
mat a4 = r(alpha)
alpha std_infcap_pca std_statecap_base_fiscal if year == 2015
mat a5 = r(alpha)
alpha std_infcap_pca std_statecap_base_fiscal_edu if year == 2015
mat a6 = r(alpha)
alpha std_infcap_pca statecap1800_baseline if year == 2015
mat a7 = r(alpha)
alpha std_infcap_pca statecapadd_baseline if year == 2015
mat a8 = r(alpha)


mat F = a1 \ a2 \ a3 \ a4 \ a5 \ a6 \ a7 \ a8
mat list F




*State Cap and Alt.*
*State Cap. Measure*
alpha std_statecap_basel std_statecap1800_baseline if year == $c_year
mat a1 = r(alpha)
alpha std_statecap_basel statecapadd_base_fiscal_edu if year == $c_year
mat a2 = r(alpha)
alpha std_statecap_basel std_statehiste05 if year == $c_year
mat a3 = r(alpha)
*alpha std_statecap_basel std_e_fh_rol if year == $c_year
*mat a4 = r(alpha)
mat A = a1 \ a2 \ a3 
mat list A

alpha std_statecap_base_fiscal std_statecap1800_baseline if year == $c_year
mat a1 = r(alpha)
alpha std_statecap_base_fiscal statecapadd_base_fiscal_edu if year == $c_year
mat a2 = r(alpha)
alpha std_statecap_base_fiscal std_statehiste05 if year == $c_year
mat a3 = r(alpha)
*alpha std_statecap_base_fiscal std_e_fh_rol if year == $c_year
*mat a4 = r(alpha)
mat B = a1 \ a2 \ a3 

*State Cap Comp*
alpha std_statecap_base_fiscal_edu std_statecap1800_baseline if year == $c_year
mat a1 = r(alpha)
alpha std_statecap_base_fiscal_edu statecapadd_base_fiscal_edu if year == $c_year
mat a2 = r(alpha)
alpha std_statecap_base_fiscal_edu std_statehiste05 if year == $c_year
mat a3 = r(alpha)
*alpha std_statecap_base_fiscal_edu std_e_fh_rol if year == $c_year
*mat a4 = r(alpha)
mat C = a1 \ a2 \ a3 

mat SCA = A, B, C
matlist SCA

*ICRG WGI FFI*
*ICRG*
alpha std_icrg_qog std_wgi_new if year == $c_year
mat a1 = r(alpha)
alpha std_icrg_qog std_ffp_fsi if year == $c_year
mat a2 = r(alpha)
alpha std_ffp_fsi std_wgi_new if year == $c_year
mat a3 = r(alpha)
*alpha std_statecap_basel std_e_fh_rol if year == $c_year
*mat a4 = r(alpha)
mat A = a1 \ a2 \ a3 
mat list A

*WGI*
alpha  std_statecap1800_baseline statecapadd_base_fiscal_edu if year == $c_year
mat a1 = r(alpha)
alpha std_statecap1800_baseline std_statehiste05 if year == $c_year
mat a2 = r(alpha)
alpha statecapadd_base_fiscal_edu std_statehiste05 if year == $c_year
mat a3 = r(alpha)
*alpha std_statecap_base_fiscal std_e_fh_rol if year == $c_year
*mat a4 = r(alpha)
mat B = a1 \ a2 \ a3 


mat SCB = A, B
matlist SCB

alpha std_statecap_basel std_statecap_base_fiscal if year == $c_year 
alpha std_statecap_basel std_statecap_base_fiscal_edu if year == $c_year 
alpha std_statecap_base_fiscal_edu std_statecap_base_fiscal if year == $c_year 



*Democracy Measures*
alpha std_statecap_basel std_v2x_polyarchy if year == $c_year
mat a1 = r(alpha)
alpha std_statecap_basel std_p_polity if year == $c_year
mat a2 = r(alpha)
alpha std_statecap_basel std_e_fh_pr if year == $c_year
mat a3 = r(alpha)
alpha std_statecap_basel std_icrg_qog  if year == $c_year
mat a4 = r(alpha)
alpha std_statecap_basel std_wgi_new if year == $c_year
mat a5 = r(alpha)
alpha std_statecap_basel std_ffp_fsi if year == $c_year
mat a6 = r(alpha)
mat A = a1 \ a2 \ a3 \ a4 \ a5 \ a6


alpha std_statecap_base_fiscal std_v2x_polyarchy if year == $c_year
mat a1 = r(alpha)
alpha std_statecap_base_fiscal std_p_polity if year == $c_year
mat a2 = r(alpha)
alpha std_statecap_base_fiscal std_e_fh_pr if year == $c_year
mat a3 = r(alpha)
alpha std_statecap_base_fiscal std_icrg_qog  if year == $c_year
mat a4 = r(alpha)
alpha std_statecap_base_fiscal std_wgi_new if year == $c_year
mat a5 = r(alpha)
alpha std_statecap_base_fiscal std_ffp_fsi if year == $c_year
mat a6 = r(alpha)
mat B = a1 \ a2 \ a3 \ a4 \ a5 \ a6

alpha std_statecap_base_fiscal_edu std_v2x_polyarchy if year == $c_year
mat a1 = r(alpha)
alpha std_statecap_base_fiscal_edu std_p_polity if year == $c_year
mat a2 = r(alpha)
alpha std_statecap_base_fiscal_edu std_e_fh_pr if year == $c_year
mat a3 = r(alpha)
alpha std_statecap_base_fiscal_edu std_icrg_qog  if year == $c_year
mat a4 = r(alpha)
alpha std_statecap_base_fiscal_edu std_wgi_new if year == $c_year
mat a5 = r(alpha)
alpha std_statecap_base_fiscal_edu std_ffp_fsi if year == $c_year
mat a6 = r(alpha)
mat C = a1 \ a2 \ a3 \ a4 \ a5 \ a6
mat list C

mat DEM = A, B, C
mat list DEM
 
 
 *More Democracy Table*
alpha std_ffp_fsi  std_v2x_polyarchy if year == $c_year
mat a1 = r(alpha)
alpha std_ffp_fsi std_p_polity if year == $c_year
mat a2 = r(alpha)
alpha std_ffp_fsi std_e_fh_pr if year == $c_year
mat a3 = r(alpha)
alpha std_ffp_fsi std_icrg_qog  if year == $c_year
mat a4 = r(alpha)
alpha std_ffp_fsi std_wgi_new if year == $c_year
mat a5 = r(alpha)
mat C2 = a1 \ a2 \ a3 \ a4 \ a5 
mat list C2

alpha std_wgi_new  std_v2x_polyarchy if year == $c_year
mat a1 = r(alpha)
alpha std_wgi_new std_p_polity if year == $c_year
mat a2 = r(alpha)
alpha std_wgi_new std_e_fh_pr if year == $c_year
mat a3 = r(alpha)
alpha std_wgi_new std_icrg_qog  if year == $c_year
mat a4 = r(alpha)
mat C3 = a1 \ a2 \ a3 \ a4 
mat list C3

alpha std_icrg_qog  std_v2x_polyarchy if year == $c_year
mat a1 = r(alpha)
alpha std_icrg_qog std_p_polity if year == $c_year
mat a2 = r(alpha)
alpha std_icrg_qog std_e_fh_pr if year == $c_year
mat a3 = r(alpha)
mat C4 = a1 \ a2 \ a3
mat list C4
 
 
alpha std_e_fh_pr  std_v2x_polyarchy if year == $c_year
mat a1 = r(alpha)
alpha std_e_fh_pr std_p_polity if year == $c_year
mat a2 = r(alpha)
mat C4 = a1 \ a2 
mat list C4

alpha std_p_polity  std_v2x_polyarchy if year == $c_year

 
**Top and Bottom Lists**

*statecap_basel
*pc3_statecap_base_fiscal_edu
global list "statecap_base_fiscal_edu"
global year 2017
keep if year == $year
foreach v in $list {
global var `v'
di "State Capacity: $var"
di "Year: $year"
gsort -$var
di "Top"
list country_* $var in 1/20
gsort $var
di "Bottom"
list country_* $var in 1/20
}
















